@@ -1,6 +1,7 @@
 #!/bin/bash
 
-autoreconf && ./configure --enable-sqlite3 --enable-aer --enable-mce --enable-extlog --enable-abrt-report
+autoreconf && ./configure --enable-all
+
 
 VER="`perl -ne 'print "$1\n" if (/Version:\s*(.*)/);' misc/rasdaemon.spec`"
 if [ "x$VER" == "x" ]; then
@@ -12,4 +13,4 @@ echo "************************************************************************"
 echo "Building RPM files for version: $VER"
 echo "************************************************************************"
 echo
-git tag v$VER -f && make mock && make upload && git push --tags master
+git tag v$VER -f && make mock && make upload && git push
